@@ -3,7 +3,7 @@
                              -------------------
     begin                : 7 Feb 2005
     copyright            : (C) 2005 by Liviu Lalescu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -17,12 +17,12 @@
 
 #include <QMessageBox>
 
+#include <QSet>
+
 #include "longtextmessagebox.h"
 
 #include "addconstraintactivitypreferredroomform.h"
-#include "spaceconstraint.h"
 
-#include <QSet>
 #include "lockunlock.h"
 
 AddConstraintActivityPreferredRoomForm::AddConstraintActivityPreferredRoomForm(QWidget* parent): QDialog(parent)
