@@ -3,7 +3,7 @@
                              -------------------
     begin                : 2009
     copyright            : (C) 2009 by Liviu Lalescu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -20,7 +20,6 @@
 #include "longtextmessagebox.h"
 
 #include "addconstraintactivitytagpreferredroomform.h"
-#include "spaceconstraint.h"
 
 AddConstraintActivityTagPreferredRoomForm::AddConstraintActivityTagPreferredRoomForm(QWidget* parent): QDialog(parent)
 {
