@@ -2,8 +2,8 @@
                           alltimeconstraintsform.cpp  -  description
                              -------------------
     begin                : Feb 10, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2005 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,8 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <Qt>
-
 #include "longtextmessagebox.h"
 
 #include "alltimeconstraintsform.h"
@@ -295,6 +293,8 @@
 
 #include "advancedfilterform.h"
 
+#include <Qt>
+
 #include <QMessageBox>
 
 #include <QPlainTextEdit>
@@ -327,8 +327,10 @@
 extern const QString COMPANY;
 extern const QString PROGRAM;
 
+//The order is important: we must have DESCRIPTION < DETDESCRIPTION, because we use std::stable_sort to put
+//the hopefully simpler/faster/easier to check filters first.
 const int DESCRIPTION=0;
-//const int DETDESCRIPTION=1;
+const int DETDESCRIPTION=1;
 
 const int CONTAINS=0;
 const int DOESNOTCONTAIN=1;
@@ -361,6 +363,10 @@ AllTimeConstraintsForm::AllTimeConstraintsForm(QWidget* parent): QDialog(parent)
 	connect(sortedCheckBox, SIGNAL(toggled(bool)), this, SLOT(sortedChanged(bool)));
 	connect(activatePushButton, SIGNAL(clicked()), this, SLOT(activateConstraint()));
 	connect(deactivatePushButton, SIGNAL(clicked()), this, SLOT(deactivateConstraint()));
+
+	connect(activateAllPushButton, SIGNAL(clicked()), this, SLOT(activateAllConstraints()));
+	connect(deactivateAllPushButton, SIGNAL(clicked()), this, SLOT(deactivateAllConstraints()));
+
 	//connect(sortByCommentsPushButton, SIGNAL(clicked()), this, SLOT(sortConstraintsByComments()));
 	connect(commentsPushButton, SIGNAL(clicked()), this, SLOT(constraintComments()));
 
@@ -370,7 +376,7 @@ AllTimeConstraintsForm::AllTimeConstraintsForm(QWidget* parent): QDialog(parent)
 	QSettings settings(COMPANY, PROGRAM);
 	if(settings.contains(this->metaObject()->className()+QString("/splitter-state")))
 		splitter->restoreState(settings.value(this->metaObject()->className()+QString("/splitter-state")).toByteArray());
-		
+	
 	QString settingsName="AllTimeConstraintsAdvancedFilterForm";
 	
 	all=settings.value(settingsName+"/all-conditions", "true").toBool();
@@ -441,65 +447,86 @@ bool AllTimeConstraintsForm::filterOk(TimeConstraint* ctr)
 	if(!caseSensitive)
 		csens=Qt::CaseInsensitive;
 	
-	QList<bool> okPartial;
+	QList<int> perm;
+	for(int i=0; i<descrDetDescr.count(); i++)
+		perm.append(i);
+	//Below we do a stable sorting, so that first inputted filters are hopefully filtering out more entries.
+	std::stable_sort(perm.begin(), perm.end(), [this](int a, int b){return descrDetDescr.at(a)<descrDetDescr.at(b);});
+	for(int i=0; i<perm.count()-1; i++)
+		assert(descrDetDescr.at(perm.at(i))<=descrDetDescr.at(perm.at(i+1)));
 	
-	for(int i=0; i<descrDetDescr.count(); i++){
-		QString s;
-		if(descrDetDescr.at(i)==DESCRIPTION)
-			s=ctr->getDescription(gt.rules);
-		else
-			s=ctr->getDetailedDescription(gt.rules);
-			
-		QString t=text.at(i);
-		if(contains.at(i)==CONTAINS){
-			okPartial.append(s.contains(t, csens));
+	int firstPosWithDescr=-1;
+	int firstPosWithDetDescr=-1;
+	for(int i=0; i<perm.count(); i++){
+		if(descrDetDescr.at(perm.at(i))==DESCRIPTION && firstPosWithDescr==-1){
+			firstPosWithDescr=i;
 		}
-		else if(contains.at(i)==DOESNOTCONTAIN){
-			okPartial.append(!(s.contains(t, csens)));
+		else if(descrDetDescr.at(perm.at(i))==DETDESCRIPTION && firstPosWithDetDescr==-1){
+			firstPosWithDetDescr=i;
+		}
+	}
+	
+	QString s=QString("");
+	for(int i=0; i<perm.count(); i++){
+		if(descrDetDescr.at(perm.at(i))==DESCRIPTION){
+			assert(firstPosWithDescr>=0);
+			
+			if(i==firstPosWithDescr)
+				s=ctr->getDescription(gt.rules);
+		}
+		else{
+			assert(descrDetDescr.at(perm.at(i))==DETDESCRIPTION);
+			
+			assert(firstPosWithDetDescr>=0);
+			
+			if(i==firstPosWithDetDescr)
+				s=ctr->getDetailedDescription(gt.rules);
+		}
+
+		bool okPartial=true; //We initialize okPartial to silence a MinGW 11.2.0 warning of type 'this variable might be used uninitialized'.
+		
+		QString t=text.at(perm.at(i));
+		if(contains.at(perm.at(i))==CONTAINS){
+			okPartial=s.contains(t, csens);
+		}
+		else if(contains.at(perm.at(i))==DOESNOTCONTAIN){
+			okPartial=!(s.contains(t, csens));
 		}
 #if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
-		else if(contains.at(i)==REGEXP){
+		else if(contains.at(perm.at(i))==REGEXP){
 			QRegularExpression regExp(t);
 			if(!caseSensitive)
 				regExp.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
-			okPartial.append((regExp.match(s)).hasMatch());
+			okPartial=(regExp.match(s)).hasMatch();
 		}
-		else if(contains.at(i)==NOTREGEXP){
+		else if(contains.at(perm.at(i))==NOTREGEXP){
 			QRegularExpression regExp(t);
 			if(!caseSensitive)
 				regExp.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
-			okPartial.append(!(regExp.match(s)).hasMatch());
+			okPartial=!(regExp.match(s)).hasMatch();
 		}
 #else
-		else if(contains.at(i)==REGEXP){
+		else if(contains.at(perm.at(i))==REGEXP){
 			QRegExp regExp(t);
 			regExp.setCaseSensitivity(csens);
-			okPartial.append(regExp.indexIn(s)>=0);
+			okPartial=(regExp.indexIn(s)>=0);
 		}
-		else if(contains.at(i)==NOTREGEXP){
+		else if(contains.at(perm.at(i))==NOTREGEXP){
 			QRegExp regExp(t);
 			regExp.setCaseSensitivity(csens);
-			okPartial.append(regExp.indexIn(s)<0);
+			okPartial=(regExp.indexIn(s)<0);
 		}
 #endif
 		else
 			assert(0);
+			
+		if(all && !okPartial)
+			return false;
+		else if(!all && okPartial)
+			return true;
 	}
 	
-	if(all){
-		bool ok=true;
-		for(bool b : qAsConst(okPartial))
-			ok = ok && b;
-			
-		return ok;
-	}
-	else{ //any
-		bool ok=false;
-		for(bool b : qAsConst(okPartial))
-			ok = ok || b;
-			
-		return ok;
-	}
+	return all;
 }
 
 void AllTimeConstraintsForm::moveTimeConstraintUp()
@@ -2046,7 +2073,7 @@ void AllTimeConstraintsForm::filter(bool active)
 	
 	assert(active);
 	
-	filterForm=new AdvancedFilterForm(this, all, descrDetDescr, contains, text, caseSensitive, "AllTimeConstraintsAdvancedFilterForm");
+	filterForm=new AdvancedFilterForm(this, tr("Advanced filter for time constraints"), false, all, descrDetDescr, contains, text, caseSensitive, "AllTimeConstraintsAdvancedFilterForm");
 
 	int t=filterForm->exec();
 	
@@ -2067,10 +2094,10 @@ void AllTimeConstraintsForm::filter(bool active)
 		contains.clear();
 		text.clear();
 			
-		assert(filterForm->descrDetDescrComboBoxList.count()==filterForm->contNContReNReComboBoxList.count());
-		assert(filterForm->descrDetDescrComboBoxList.count()==filterForm->textLineEditList.count());
+		assert(filterForm->descrDetDescrDetDescrWithConstraintsComboBoxList.count()==filterForm->contNContReNReComboBoxList.count());
+		assert(filterForm->descrDetDescrDetDescrWithConstraintsComboBoxList.count()==filterForm->textLineEditList.count());
 		for(int i=0; i<filterForm->rows; i++){
-			QComboBox* cb1=filterForm->descrDetDescrComboBoxList.at(i);
+			QComboBox* cb1=filterForm->descrDetDescrDetDescrWithConstraintsComboBoxList.at(i);
 			QComboBox* cb2=filterForm->contNContReNReComboBoxList.at(i);
 			QLineEdit* tl=filterForm->textLineEditList.at(i);
 			
@@ -2214,6 +2241,81 @@ void AllTimeConstraintsForm::deactivateConstraint()
 	constraintsListWidget->setFocus();
 }
 
+void AllTimeConstraintsForm::activateAllConstraints()
+{
+	QMessageBox::StandardButton ret=QMessageBox::No;
+	QString s=tr("Are you sure you want to activate all the listed time constraints?");
+	ret=QMessageBox::warning(this, tr("FET warning"), s, QMessageBox::Yes|QMessageBox::No, QMessageBox::No);
+	if(ret==QMessageBox::No){
+		constraintsListWidget->setFocus();
+		return;
+	}
+
+	int cnt=0;
+	bool recomputeTime=false;
+	for(TimeConstraint* ctr : qAsConst(visibleTimeConstraintsList)){
+		if(!ctr->active){
+			cnt++;
+			ctr->active=true;
+			if(ctr->type==CONSTRAINT_ACTIVITY_PREFERRED_STARTING_TIME)
+				recomputeTime=true;
+		}
+	}
+	if(cnt>0){
+		gt.rules.internalStructureComputed=false;
+		setRulesModifiedAndOtherThings(&gt.rules);
+		
+		filterChanged();
+		
+		QMessageBox::information(this, tr("FET information"), tr("Activated %1 time constraints").arg(cnt));
+	}
+	if(recomputeTime){
+		LockUnlock::computeLockedUnlockedActivitiesOnlyTime();
+		LockUnlock::increaseCommunicationSpinBox();
+	}
+	
+	constraintsListWidget->setFocus();
+}
+
+void AllTimeConstraintsForm::deactivateAllConstraints()
+{
+	QMessageBox::StandardButton ret=QMessageBox::No;
+	QString s=tr("Are you sure you want to deactivate all the listed time constraints? "
+	 "(Note that the basic compulsory time constraints will not be deactivated, even if they are in the list.)");
+	ret=QMessageBox::warning(this, tr("FET warning"), s, QMessageBox::Yes|QMessageBox::No, QMessageBox::No);
+	if(ret==QMessageBox::No){
+		constraintsListWidget->setFocus();
+		return;
+	}
+
+	int cnt=0;
+	bool recomputeTime=false;
+	for(TimeConstraint* ctr : qAsConst(visibleTimeConstraintsList)){
+		if(ctr->type==CONSTRAINT_BASIC_COMPULSORY_TIME)
+			continue;
+		if(ctr->active){
+			cnt++;
+			ctr->active=false;
+			if(ctr->type==CONSTRAINT_ACTIVITY_PREFERRED_STARTING_TIME)
+				recomputeTime=true;
+		}
+	}
+	if(cnt>0){
+		gt.rules.internalStructureComputed=false;
+		setRulesModifiedAndOtherThings(&gt.rules);
+		
+		filterChanged();
+		
+		QMessageBox::information(this, tr("FET information"), tr("Deactivated %1 time constraints").arg(cnt));
+	}
+	if(recomputeTime){
+		LockUnlock::computeLockedUnlockedActivitiesOnlyTime();
+		LockUnlock::increaseCommunicationSpinBox();
+	}
+	
+	constraintsListWidget->setFocus();
+}
+
 /*static int timeConstraintsAscendingByComments(const TimeConstraint* t1, const TimeConstraint* t2)
 {
 	return t1->comments < t2->comments;
