@@ -2,8 +2,8 @@
                           helpaboutform.cpp  -  description
                              -------------------
     begin                : Tue Apr 22 2003
-    copyright            : (C) 2003 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2003 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -76,10 +76,10 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	about+=tr("FET is free software for automatically scheduling the timetable of a school, high-school or university.");
 	about+="<br /><br />";
 	about+=tr("Copyright (C) %1 %2.", "%1 is the copyright period (a range between two years, more years separated by commas, "
-	 "or a combination of these), %2 are the copyright holders").arg("2002-2022").arg("Liviu Lalescu, Volker Dirr");
+	 "or a combination of these), %2 are the copyright holders").arg("2002-2023").arg("Liviu Lalescu, Volker Dirr");
 	about+="<br /><br />";
 	about+=tr("Version: %1 (%2 %3).", "%1 is the current FET version, %2 is the current release month, %3 is the current release year").arg(FET_VERSION)
-	 .arg(QCoreApplication::translate("MonthsNames", "December")).arg("2022");
+	 .arg(QCoreApplication::translate("MonthsNames", "January")).arg("2023");
 	about+="<br /><br />";
 	about+=tr("Licensed under the GNU Affero General Public License version 3 or later.");
 	about+="<br /><br />";
@@ -757,7 +757,7 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	thanksTo+=QString("<br />");
 	thanksTo+=QString("orange");
 	thanksTo+=QString("<br />");
-	thanksTo+=QString("nguyenhuuduyet");
+	thanksTo+=QString::fromUtf8("Nguyễn Hữu Duyệt");
 	thanksTo+=QString("<br />");
 	thanksTo+=QString("Vanyo Georgiev");
 	thanksTo+=QString("<br />");
@@ -1137,6 +1137,10 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	thanksTo+=QString("<br />");
 	thanksTo+=QString("giardiniere");
 	thanksTo+=QString("<br />");
+	thanksTo+=QString("darkwindow");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("castonepatha");
+	thanksTo+=QString("<br />");
 
 	thanksToTextBrowser->setHtml(thanksTo);
 }
